==> primefaces-extensions-13.0.19-sources.jar: org/primefaces/extensions/component/imagezoom/ImageZoomRenderer.java <==
/*
 * Copyright (c) 2011-2024 PrimeFaces Extensions
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *  THE SOFTWARE.
 */
package org.primefaces.extensions.component.imagezoom;

import java.io.IOException;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;

import org.primefaces.expression.SearchExpressionFacade;
import org.primefaces.renderkit.CoreRenderer;
import org.primefaces.util.WidgetBuilder;

/**
 * Renderer for the {@link ImageZoom} component.
 *
 * @author Melloware
 * @since 11.0.3
 */
public class ImageZoomRenderer extends CoreRenderer {

    @Override
    public void encodeEnd(final FacesContext context, final UIComponent component) throws IOException {
        final ImageZoom imageZoom = (ImageZoom) component;
        final WidgetBuilder wb = getWidgetBuilder(context);
        wb.init("ImageZoom", imageZoom);
        wb.attr("target", SearchExpressionFacade.resolveClientId(context, imageZoom, imageZoom.getFor()))
                    .attr("margin", imageZoom.getMargin(), 0)
                    .attr("scrollOffset", imageZoom.getScrollOffset(), 40)
                    .attr("background", imageZoom.getBackground(), "#fff")
                    .attr("container", imageZoom.getContainer(), "#fff")
                    .attr("template", imageZoom.getTemplate(), "#fff");
        wb.finish();
    }
}

==> primefaces-extensions-14.0.5-sources.jar: org/primefaces/extensions/component/imagezoom/ImageZoomRenderer.java <==
/*
 * Copyright (c) 2011-2024 PrimeFaces Extensions
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *  THE SOFTWARE.
 */
package org.primefaces.extensions.component.imagezoom;

import java.io.IOException;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;

import org.primefaces.expression.SearchExpressionUtils;
import org.primefaces.renderkit.CoreRenderer;
import org.primefaces.util.WidgetBuilder;

/**
 * Renderer for the {@link ImageZoom} component.
 *
 * @author Melloware
 * @since 11.0.3
 */
public class ImageZoomRenderer extends CoreRenderer {

    @Override
    public void encodeEnd(final FacesContext context, final UIComponent component) throws IOException {
        final ImageZoom imageZoom = (ImageZoom) component;
        final WidgetBuilder wb = getWidgetBuilder(context);
        wb.init("ImageZoom", imageZoom);
        wb.attr("target", SearchExpressionUtils.resolveClientIdsForClientSide(context, imageZoom, imageZoom.getFor()))
                    .attr("margin", imageZoom.getMargin(), 0)
                    .attr("scrollOffset", imageZoom.getScrollOffset(), 40)
                    .attr("background", imageZoom.getBackground(), "#fff")
                    .attr("container", imageZoom.getContainer(), "#fff")
                    .attr("template", imageZoom.getTemplate(), "#fff");
        wb.finish();
    }
}
